/**
 * @file memory_driver_template.h
 * @brief CycloneBOOT Memory Driver Template
 *
 * @section License
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.0
 **/

#ifndef _FLASH_DRIVER_TEMPLATE_H
#define _FLASH_DRIVER_TEMPLATE_H

//Dependencies
#include <stdlib.h>
#include <stdint.h>
#include "error.h"

//FLASH name
#define FLASH_NAME "FLASH Internal Flash"
//FLASH start addr
#define FLASH_ADDR 0x08000000
//FLASH size
#define FLASH_SIZE 0x100000
//FLASH write size
#define FLASH_WRITE_SIZE 0x04 //4-bytes word
//FLASH read size
#define FLASH_READ_SIZE 0x04 //4-bytes word

//FLASH sectors number
#define FLASH_SECTORS_NUMBER 12

//FLASH Sector start address list
#define FLASH_SECTOR_0_ADDR   0x08000000 //Base address of Sector 0,  End address at 0x08003FFF, 16 Kbytes   | 16 Kbytes
#define FLASH_SECTOR_1_ADDR   0x08004000 //Base address of Sector 1,  End address at 0x08007FFF, 16 Kbytes   | 32 Kbytes
#define FLASH_SECTOR_2_ADDR   0x08008000 //Base address of Sector 2,  End address at 0x0800BFFF, 16 Kbytes   | 48 Kbytes
#define FLASH_SECTOR_3_ADDR   0x0800C000 //Base address of Sector 3,  End address at 0x0800FFFF, 16 Kbytes   | 64 Kbytes
#define FLASH_SECTOR_4_ADDR   0x08010000 //Base address of Sector 4,  End address at 0x0801FFFF, 64 Kbytes   | 128 Kbytes
#define FLASH_SECTOR_5_ADDR   0x08020000 //Base address of Sector 5,  End address at 0x0803FFFF, 128 Kbytes  | 256 Kbytes
#define FLASH_SECTOR_6_ADDR   0x08040000 //Base address of Sector 6,  End address at 0x0805FFFF, 128 Kbytes  | 384 Kbytes
#define FLASH_SECTOR_7_ADDR   0x08060000 //Base address of Sector 7,  End address at 0x0807FFFF, 128 Kbytes  | 512 Kbytes
#define FLASH_SECTOR_8_ADDR   0x08080000 //Base address of Sector 8,  End address at 0x0809FFFF, 128 Kbytes  | 640 Kbytes
#define FLASH_SECTOR_9_ADDR   0x080A0000 //Base address of Sector 9,  End address at 0x080BFFFF, 128 Kbytes  | 768 Kbytes
#define FLASH_SECTOR_10_ADDR  0x080C0000 //Base address of Sector 10, End address at 0x080DFFFF, 128 Kbytes  | 896 Kbytes
#define FLASH_SECTOR_11_ADDR  0x080E0000 //Base address of Sector 11, End address at 0x080FFFFF, 128 Kbytes  | 1024 Kbytes

//FLASH Sectors size list
#define FLASH_SECTOR_0_SIZE   0x4000
#define FLASH_SECTOR_1_SIZE   0x4000
#define FLASH_SECTOR_2_SIZE   0x4000
#define FLASH_SECTOR_3_SIZE   0x4000
#define FLASH_SECTOR_4_SIZE   0x10000
#define FLASH_SECTOR_5_SIZE   0x20000
#define FLASH_SECTOR_6_SIZE   0x20000
#define FLASH_SECTOR_7_SIZE   0x20000
#define FLASH_SECTOR_8_SIZE   0x20000
#define FLASH_SECTOR_9_SIZE   0x20000
#define FLASH_SECTOR_10_SIZE  0x20000
#define FLASH_SECTOR_11_SIZE  0x20000

#endif //!_FLASH_DRIVER_TEMPLATE_H
