/**
 * @file iap_driver.h
 * @brief CycloneBOOT IAP driver interface
 *
 * @section License
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.0
 **/

#ifndef _IAP_DRIVER_H
#define _IAP_DRIVER_H

//Dependencies
#include <stdlib.h>
#include <stdint.h>
//#include "iap_config.h"
#include "error.h"

//Flash driver version 1.0.1
#define FLASH_DRIVER_MAJOR_VERS  (0x01 << 16)   //Flash driver major version
#define FLASH_DRIVER_MINOR_VERS  (0x00 << 8)    //Flash driver minor version  
#define FLASH_DRIVER_PATCH_VERS  (0x01 << 0)    //Flash driver patch version
#define FLASH_DRIVER_VERSION     (FLASH_DRIVER_MAJOR_VERS || FLASH_DRIVER_MINOR_VERS || FLASH_DRIVER_PATCH_VERS)

#define FLASH_SECTOR_MAX_NUMBER     64    //Maximum number of flash sector
#define FLASH_BANK_MAX_NUMBER       2     //Maximum number of flash banks
#define FLASH_WRITE_TYPE_BYTE       0     //Byte 8-bits write type
#define FLASH_WRITE_TYPE_HALFWORD   1     //Half Word 16-bits write type 
#define FLASH_WRITE_TYPE_WORD       2     //Word 32-bits write type


///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////
///////////////////////////////////////////////////////////////////////////////


/**
 * @brief Flash Sector description
 **/

typedef struct{
  uint32_t id;
  unsigned long size;    // Sector Size in Bytes
  uint32_t addr;  // Address of Sector
}FlashSectors;


/**
 * @brief Flash Bank description
 **/

typedef FlashSectors FlashBanks;


/**
 * @brief Common interface for flash memory
 **/

typedef struct
{
   uint32_t version;
   uint32_t addr;
   unsigned long size;
   uint8_t writeType;
   FlashBanks banks[FLASH_BANK_MAX_NUMBER]; 
   FlashSectors sectors[FLASH_SECTOR_MAX_NUMBER];
} FlashDriver;


//IAP driver common flash interface related functions 
extern error_t flashInit(void);
extern error_t flashGetStartAddr(uint32_t *address);
extern size_t flashGetBankSize(void);
extern error_t flashWriteByte(uint32_t address, uint8_t byte);
extern error_t flashWriteHalfWord(uint32_t address, uint16_t halfword);
extern error_t flashWriteWord(uint32_t address, uint32_t word);
extern error_t flashSwapBank(void);
extern void systemReset(void);

#endif //!_IAP_DRIVER_H
