/**
 * @file stm32l5xx_crypto_pkc.h
 * @brief STM32L5 public-key hardware accelerator (PKA)
 *
 * @section License
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneCRYPTO Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.0
 **/

#ifndef _STM32L5XX_CRYPTO_PKC_H
#define _STM32L5XX_CRYPTO_PKC_H

//Dependencies
#include "core/crypto.h"

//Public-key hardware accelerator
#ifndef STM32L5XX_CRYPTO_PKC_SUPPORT
   #define STM32L5XX_CRYPTO_PKC_SUPPORT DISABLED
#elif (STM32L5XX_CRYPTO_PKC_SUPPORT != ENABLED && STM32L5XX_CRYPTO_PKC_SUPPORT != DISABLED)
   #error STM32L5XX_CRYPTO_PKC_SUPPORT parameter is not valid
#endif

//Maximum RSA operand size, in bytes
#define STM32L5XX_MAX_ROS 392
//Maximum ECC operand size, in bytes
#define STM32L5XX_MAX_EOS 80

//C++ guard
#ifdef __cplusplus
extern "C" {
#endif


/**
 * @brief RSA primitive arguments
 **/

typedef struct
{
   uint8_t a[STM32L5XX_MAX_ROS];
   uint8_t d[STM32L5XX_MAX_ROS];
   uint8_t e[STM32L5XX_MAX_ROS];
   uint8_t n[STM32L5XX_MAX_ROS];
   uint8_t p[STM32L5XX_MAX_ROS];
   uint8_t q[STM32L5XX_MAX_ROS];
   uint8_t dp[STM32L5XX_MAX_ROS];
   uint8_t dq[STM32L5XX_MAX_ROS];
   uint8_t qinv[STM32L5XX_MAX_ROS];
} Stm32l5xxRsaArgs;


/**
 * @brief ECC primitive arguments
 **/

typedef struct
{
   uint8_t p[STM32L5XX_MAX_EOS];
   uint8_t a[STM32L5XX_MAX_EOS];
   uint8_t gx[STM32L5XX_MAX_EOS];
   uint8_t gy[STM32L5XX_MAX_EOS];
   uint8_t q[STM32L5XX_MAX_EOS];
   uint8_t h[STM32L5XX_MAX_EOS];
   uint8_t k[STM32L5XX_MAX_EOS];
   uint8_t d[STM32L5XX_MAX_EOS];
   uint8_t qx[STM32L5XX_MAX_EOS];
   uint8_t qy[STM32L5XX_MAX_EOS];
   uint8_t r[STM32L5XX_MAX_EOS];
   uint8_t s[STM32L5XX_MAX_EOS];
} Stm32l5xxEccArgs;


//PKA related functions
error_t pkaInit(void);

//C++ guard
#ifdef __cplusplus
}
#endif

#endif
