## Getting started with http_server_iap_single_bank_demo

This demonstration project provided for the stm32f769i_disco contains a HTTP server and CycloneBOOT IAP middleware. The HTTP server will manage the reception of the update image. The CycloneBOOT IAP middleware will manage the processing of the image fetched by the HTTP server. In "Single Bank" mode, the CycloneBOOT IAP middleware will employ a static bootloader as well.

This demo makes uses of a MCU with a single bank flash and an external memory. It also requires a static bootloader in flash. The current application firmware is located in a special format (known "internal image" in the accompanying user manual) just after the bootloader. 
When an update is receieved, the CycloneBOOT IAP middleware called by the user application will process the update image and store it in a special format in the external memory. 
If the update image is valid, then the system is rebooted and the static bootloader completes the update process by transfering the new application firmware from the external memory to the internal flash.

This demonstration project showcase several update scenarios: 

- scenario 1 : plaintext firmware + integrity (CRC32)
- scenario 2 : cipher firmware + authentication (AES-CBC + HMAC-MD5)
- scenario 3 : cipher firmware + signature (AES-CBC + RSA-SHA256)

For purposes of demonstration, the background color of the update web page and the displayed version of the application can be changed at compilation. For this you need to edit several macros in the file `version.h` in `stm32f769i_disco\http_server_iap_single_bank_demo\src` directory. 

Here is an example if you want to generate an application firmware with a `red` background web page and the version `v2.5.1`:

```c
//Version string
#define APP_VERSION_STRING "2.5.1"
//Major version
#define APP_MAJOR_VERSION 2
//Minor version
#define APP_MINOR_VERSION 5
//Revision number
#define APP_REV_NUMBER 1
//Version color
#define APP_VERSION_COLOR "#FF0000" // RED hex color code
```

> Note: By default the version is `v1.0.0` and the color is yellow (`#FFE082`)

### Step #0 : Prerequisites 

  - Download and install STLink Utility : https://www.st.com/en/development-tools/stsw-link004.html. Make sure to add the ST-LINK_CLI.exe in to your PATH.
  
    Note: You can also use the newer STM32CubeProgrammer as well. However, you may need to adjust the steps below to follow along with STM32CubeProgrammer. Please refer to its documentation for more information.

### Step #1 : Board configuration

In this step, we will configure the stm32f769i_disco MCU to accept our project(s). More precisely, the MCU will be configured to run in single bank mode (single flash bank).

Plug the stm32f769i_disco to your computer.

**Manual method**: 

Run the following commands (making sure ST-LINK_CLI.exe is in your PATH): `ST-LINK_CLI.exe -c ID=0 SWD -OB nDBANK=1 nDBOOT=1 BOOT_ADD0=0x2000 BOOT_ADD1=0x2040`

**Using the provided script**:

1. Navigate to `stm32f769i_disco/scripts` directory.
2. Run the `configure_single_bank_mode.bat` script.
3. Your board is now ready.

> **Important:** This step (*Step #1*) is only needed if the MCU has a dual bank flash to make sure the flash is seen as a single bank flash.

### Step #2 : Program the static bootloader

When using CycloneBOOT in single bank mode a satic bootloader is needed to manage a part of the update process and also to boot the application firmware next to it in internal flash.

First of all open the `micro_bootloader_demo` using Keil or another IDE/compiler then compile the project.

You should see this binary file `micro_bootloader_demo.bin` in `stm32f769i_disco\micro_bootloader_demo` directory. 

Then the bootloader MUST be put at the begining of the flash (here 0x08000000). You can perform this last step either manually or by running the provided script.

**Manual Method** : 

Use this command to programm the bootloader binary at flash start: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -P ..\micro_bootloader_demo\micro_bootloader_demo.bin 0x08000000` 

**Using the provided script** :

1. Navigate to `stm32f769i_disco/scripts` directory.
2. Run the `load_bootloader.bat` script.

### Step #3 : Generate demo firmware binaries

As the bootloader is placed at the begining of the flash, the demo firmware MUST be compiled to start with an offset which combines bootloader size and VTOR offset rules. In this case the demo is configured to start at 0x08010400.

1. Open the http_server_iap_single_bank_demo project : `stm32f769i_disco/http_server_iap_single_bank_demo/keil/http_server_iap_single_bank_demo.uvprojx`
2. Depending the choosen scenario, select the corresponding compilation profile. It can be one of these profile:
    - `scenario_1_simple_app_and_integrity`
    - `scenario_2_cipher_app_and_authentication`
    - `scenario_3_cipher_app_and_signature`
3. Clean then Build or Recompile the project
4. You should see this binary file `http_server_iap_single_bank_demo.bin` in `stm32f769i_disco\http_server_iap_single_bank_demo` directory

> **Tips:** You can change the version and the backgroud web page color of the demo application before compilation, as explained at the begining of this readme.

> Note: 
> - The scenario choosed for the compilation will reflect the type of image that CycloneBOOT IAP middleware will be able to manage.
> - If you want to change the scenario you MUST recompile the demo selecting the corresponding compilation profile  

### Step #4 : Generate demo firmware image updates

This step will transform the binary generated (at *Step #3*) in to an image file recognizable by CycloneBOOT. Regarding the chosen scenario used to build the current running firmware, the application will expect an update image generated for the same scenario.

Have a look to the function `httpServerRequestCallback()` in the `stm32f769i_disco\http_server_iap_single_bank_demo\src\http_server_callbacks.c` file to know which settings has been used to configure CycloneBOOT IAP in the demo application. These settings MUST match the options specified to generate the update image in regards to the choosen scenario.  

You can perform these steps either manually or by running the provided script. 

**Manual Method** : 

From within the demo project directory, execute the following command for:
- Scenario 1: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_single_bank_demo.bin -output http_server_iap_single_bank_demo_image_scenario_1.img -fv X.X.X`
- Scenario 2: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_single_bank_demo.bin -output http_server_iap_single_bank_demo_image_scenario_2.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -a hmac-md5 -ak 107b8d4bf62d1c9e26968e8ff51a74df`
- Scenario 3: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_single_bank_demo.bin -output http_server_iap_single_bank_demo_image_scenario_3.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -s rsa-sha256 -sk ../../http_server_iap_single_bank_demo/resources/keys/rsa_private_key.pem`


**Using the provided script** :

Run `generate_http_server_iap_single_bank_update_images.bat` in `./scripts` directory

- It will produce 3 images from the http_server_iap_single_bank_demo.bin` binary file, one for each scenario:
    - http_server_iap_single_bank_demo_image_scenario_1.img
    - http_server_iap_single_bank_demo_image_scenario_2.img
    - http_server_iap_single_bank_demo_image_scenario_3.img

Those images are generated in `./scripts` directory.

> Note: The *`-fv X.X.X`* command line option serves to indicate the version of the firmware application binary. You are free to specify another version. 

### Step #5 : Setup Initial firmware

The CycloneBOOT static bootloader is responsible for checking the validity of the firmware and then to boot the firmware if it's valid. To check the validity of the firmware,the static bootloader needs some information. 

A special image (internal image) that contains the firmware and other necessary information is expected by the static bootloader. The 'internal image' is generate in such a way that it incorporates the correct firmware start address (after the static bootloader) and relevant VTOR offset rules.

- First, we MUST erase the external flash memory to avoid any previous update images to triggerring an update at startup. 
- Second, we need to generate an 'internal image' from the demo firmware binary.
- Finally, we can program the internal flash memory to store the internal image after the bootloader at 0x08010000.

These steps can be performed manually or using dedicated scripts.

**Manual Method** :

From within the demo project directory, execute the following commands to: 
- Erase external flash memory **(1\*)**: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -SE 0 31 -EL "C:\Program Files (x86)\STMicroelectronics\STM32 ST-LINK Utility\ST-LINK Utility\ExternalLoader\MX25L512G_STM32F769I-DISCO.stldr"`
- Generate internal image: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input http_server_iap_single_bank_demo.bin -output http_server_iap_single_bank_demo_image_int.img -fv 1.0.0 -int`
- Copy the internal image into a binary (.bin) file:
`copy http_server_iap_single_bank_demo_image_int.img http_server_iap_single_bank_demo_image_int.img.bin`
- Load internal image into flash: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -P http_server_iap_single_bank_demo_image_int.img.bin 0x08010000`

**Using the provided script** :

From ./scripts directory, run the following script to:
- Erase external flash memory **(1\*)**: `erase_external_flash.bat`
- Generate internal image: `generate_http_server_iap_single_bank_internal_image.bat`. You will get this image `http_server_iap_single_bank_demo_image_int.img` in ./scripts directory.
- Load internal image into flash: `load_http_server_iap_single_bank_internal_image.bat`

> Note: 
> - **(1\*)** : This command is only an example to erase an external flash of an STM32 board (nucleo/disco/eval). It may not be available for your board as it is. 

### Step #6 : Test the Demo

**Note: Remember that the demo expects a specific scenario that has been chosen and the update image MUST also match that scenario.**

1. Configure the board in single bank mode as explained in *Step #1* (only needed for MCU that support dual bank flash), if it is not yet done. Otherwise, skip this step.
2. Load static bootloader as explained in *Step #2*, if it is not yet done. Else skip this step.
3. Compile the demo for the choosen scenario as explained in *Step #3*, if it is not yet done. Else skip this step.
4. Generate and load internal image for the inital firmware as explained in *Step #5*.
5. Generate firmware update image as explained in *Step #4* in regards of the chosen scenario.
6. Open your favorite serial console (115200 bauds). 
7. Click on the reset button to restart the demo.
8. Connect the board to a router with an Ethernet cable.
9. Get the IP address of the board from the serial console output.
10. Open a web browser and then navigate to the IP address of the board.
11. You should be able to see a button to select the firmware update image.
12. Click on `Choose` button and select the `http_server_iap_single_bank_demo_image_scenario_X.img` according the scenario.
13. Click on `Upload` to upload the image on to the server. If the update process is OK then the board will automatically reboot.
14.  You shoud get an update web page reflecting the new firmware.
15.  You can reproduce the step *12.* to *15.* by adapting the image file. 


> **Tips:** You can also redo step *3.* followed by step *5.* to change the version and the background web page color of the application. This way you will be able to see the background web color and displayed application version change at each update (step *12.* to *15.*).  

> Note: If you want to test another scenario restart from step *3.*