/**
 * @file iap_config.h
 * @brief CycloneBOOT IAP configuration file
 *
 * @section License
 *
 * Copyright (C) 2010-2022 Oryx Embedded SARL. All rights reserved.
 *
 * This file is part of CycloneBOOT Eval.
 *
 * This software is provided in source form for a short-term evaluation only. The
 * evaluation license expires 90 days after the date you first download the software.
 *
 * If you plan to use this software in a commercial product, you are required to
 * purchase a commercial license from Oryx Embedded SARL.
 *
 * After the 90-day evaluation period, you agree to either purchase a commercial
 * license or delete all copies of this software. If you wish to extend the
 * evaluation period, you must contact sales@oryx-embedded.com.
 *
 * This evaluation software is provided "as is" without warranty of any kind.
 * Technical support is available as an option during the evaluation period.
 *
 * @author Oryx Embedded SARL (www.oryx-embedded.com)
 * @version 2.0.0
 **/

#ifndef _IAP_CONFIG_H
#define _IAP_CONFIG_H

//Trace level for CycloneBOOT IAP stack debugging
#define IAP_TRACE_LEVEL          4

//IAP Single Bank Mode support
#define IAP_SINGLE_BANK_SUPPORT ENABLED
//IAP Dual Bank Mode support
#define IAP_DUAL_BANK_SUPPORT DISABLED

//IAP external flash memory encryption support
//#define IAP_EXT_MEM_ENCRYPTION_SUPPORT ENABLED

//IAP fallback support
//#define IAP_FALLBACK_SUPPORT ENABLED

//Bootloader size (sum of occupied sector size)
#define BOOTLOADER_SIZE 65536 // 32K, supposing it occupies the first 2 Flash sectors

#if defined(IAP_SCENARIO_2)

//IAP encryption support
#define IAP_ENCRYPTION_SUPPORT ENABLED
//IAP integrity support
#define IAP_INTEGRITY_SUPPORT DISABLED
//IAP authentication support
#define IAP_AUTHENTICATION_SUPPORT ENABLED

#elif defined(IAP_SCENARIO_3)

//IAP integrity support
#define IAP_INTEGRITY_SUPPORT DISABLED
//IAP signature support
#define IAP_ENCRYPTION_SUPPORT ENABLED
//IAP authentication support
#define IAP_SIGNATURE_SUPPORT ENABLED
//IAP RSA signature support
#define IAP_RSA_SUPPORT ENABLED

#else

//IAP integrity support
#define IAP_INTEGRITY_SUPPORT ENABLED

#endif

#endif //!_IAP_CONFIG_H
