 ## Getting started with https_client_iap_single_bank_demo

This demonstration project provided for the stm32f769i_disco contains a HTTPS client and CycloneBOOT IAP middleware. The HTTPS client will fetch the update image from a web server. The CycloneBOOT IAP middleware will then manage the processing of the update image. In "Single Bank" mode, the CycloneBOOT IAP middleware will employ a static bootloader as well.

When you press the user button of the stm32f769i_disco board it triggers an update procedure that will perform a firmware update on the current application firmware. To make the update process more visual, we provide 3 different update images with a specific blinking LED color : RED, GREEN or BLUE (depending on the development board). The update image selected to be downloaded follows a specific cycle:
- RED blinking LED image downloads GREEN blinking LED image
- GREEN blinking LED image downloads BLUE blinking LED image
- BLUE blinking LED image downloads RED blinking LED image

This demo makes uses of an MCU with a single bank internal flash and an external memory. It also employs a static bootloader in its internal flash. The current application firmware is located in a special format (internal image) just after the bootloader inside the main internal flash memory. 
When an update occurs the CycloneBOOT IAP middleware inside the application process an update image and stores it in a special format in the external memory. 
If the update image is valid then the MCU is rebooted and the static bootloader will complete the update process by transfering the new application firmware from the external memory to the internal flash.

It contains several update scenarios: 

- scenario 1 : plaintext firmware + integrity (CRC32)
- scenario 2 : cipher firmware + authentication (AES-CBC + HMAC-MD5)
- scenario 3 : cipher firmware + signature (AES-CBC + RSA-SHA256)
  
For this demonstration, a web server that you can access to upload an update image is a prerequisite. You can specify your web server by editing several macros in the file `http_user.c` in  `stm32f769i_disco\https_client_iap_single_bank_demo\src` directory. 

Here is an example if you want to download an update image from the Oryx Web Server:

```c
//Application configuration
//HTTPS Web Server hostname
#define APP_HTTP_SERVER_NAME "www.oryx-embedded.com"
//HTTPS Web Server port
#define APP_HTTP_SERVER_PORT 443

...

//Update image uri path
#define APP_HTTP_URI "<update-image-uri>"
```

> Note: This demo is configured to use the Oryx Web Server `www.oryx-embedded.com` on port `443`. 

### Step #0 : Prerequisites 

  - Download and install STLink Utility : https://www.st.com/en/development-tools/stsw-link004.html. Make sure to add the ST-LINK_CLI.exe in to your PATH.
  
    Note: You can also use the newer STM32CubeProgrammer as well. However, please refer to its documentation to learn more on how to adapt the following steps to use that software.

### Step #1 : Board configuration

In this step, we will configure the stm32f769i_disco MCU to accept our project(s). In particular, the MCU will be configured to run in single bank mode (single flash bank).

Plug the stm32f769i_disco to your computer.

**Manual method**: 

Run the following commands (making sure ST-LINK_CLI.exe is in your PATH): `ST-LINK_CLI.exe -c ID=0 SWD -OB nDBANK=1 nDBOOT=1 BOOT_ADD0=0x2000 BOOT_ADD1=0x2040`

**Using the provided script**:

1. Navigate to `stm32f769i_disco/scripts` directory.
2. Run the `configure_single_bank_mode.bat` script.
3. Your board is now ready.

> **Important:** This step (*Step #1*) is only needed if the MCU has a dual bank flash to make sure the flash is seen as a single bank flash.

### Step #2 : Program the static bootloader

When using CycloneBOOT in single bank mode a satic bootloader is needed to manage a part of the update process and also to boot the application firmware next to it in internal flash.

First of all open the `micro_bootloader_demo` using Keil or another IDE/compiler then compile the project.

You should see this binary file `micro_bootloader_demo.bin` in `stm32f769i_disco\micro_bootloader_demo` directory. 

Then the bootloader MUST be put at the begining of the flash (here 0x08000000). You can perform this last step either manually or by running the provided script.

**Manual Method** : 

Use this command to programm the bootloader binary at flash start: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -P ..\micro_bootloader_demo\micro_bootloader_demo.bin 0x08000000` 

**Using the provided script** :

1. Navigate to `stm32f769i_disco/scripts` directory.
2. Run the `load_bootloader.bat` script.

### Step #3 : Generate demo firmware binaries

As the bootloader is placed at the begining of the flash, the demo firmware MUST be compiled to start with an offset which combines bootloader size and VTOR offset rules. It this case the demo is configured to start at 0x08010400.

1. Open the https_client_iap_single_bank_demo project : `stm32f769i_disco/https_client_iap_single_bank_demo/keil/https_client_iap_single_bank_demo.uvprojx`
2. Depending the choosen scenario, select the corresponding compilation profile. It can be one of these profile:
    - `scenario_1_simple_app_and_integrity`
    - `scenario_2_cipher_app_and_authentication`
    - `scenario_3_cipher_app_and_signature`
3. Clean then Build or Recompile the project
4. You should see this binary file `https_client_iap_single_bank_demo.bin` in `stm32f769i_disco\https_client_iap_single_bank_demo` directory

> **Tips:** You can change the version and the backgroud web page color of the demo application before compilation, as explained at the begining of this readme.

> Note: 
> - The scenario choosed for the compilation will reflect the type of image that CycloneBOOT IAP middleware will be able to manage.
> - If you want to change the scenario you MUST recompile the demo selecting the corresponding compilation profile 


### Step #4 : Generate demo firmware image updates

This step will transform the binary generated (at *Step #3*) in to an image file recognizable by CycloneBOOT. Regarding the chosen scenario used to build the current running firmware, the application will be expecting an update image generated for the same scenario.

Have a look to the function `httpUserUpdate()` in the `stm32f769i_disco\https_client_iap_single_bank_demo\src\http_user.c` file to know which settings have been used to configure CycloneBOOT IAP in the demo application. These settings MUST match the options specified to generate the update image with regards to the choosen scenario. 

You can perform these steps either manually or by running the provided script. 

**Manual Method** : 

From within the demo project directory, execute the following command for:
- Scenario 1: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input https_client_iap_single_bank_demo.bin -output https_client_iap_single_bank_demo_image_scenario_1.img -fv X.X.X`
- Scenario 2: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input https_client_iap_single_bank_demo.bin -output https_client_iap_single_bank_demo_image_scenario_2.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -a hmac-md5 -ak 107b8d4bf62d1c9e26968e8ff51a74df`
- Scenario 3: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input https_client_iap_single_bank_demo.bin -output https_client_iap_single_bank_demo_image_scenario_3.img -fv X.X.X -ek aa3ff7d43cc015682c7dfd00de9379e7 -s rsa-sha256 -sk ../../https_client_iap_single_bank_demo/resources/keys/rsa_private_key.pem`


**Using the provided script** :

Run `generate_https_client_iap_single_bank_update_images.bat` in `../scripts` directory

- It will produce 3 images from the https_client_iap_single_bank_demo.bin` binary file, one for each scenario:
    - https_client_iap_single_bank_demo_image_scenario_1.img
    - https_client_iap_single_bank_demo_image_scenario_2.img
    - https_client_iap_single_bank_demo_image_scenario_3.img

Those images are generated in `../scripts` directory.

> Note: The *`-fv X.X.X`* command line option serves to indicate the version of the firmware application binary. You are free to specify an another version. 

### Step #5 : Setup Initial firmware

The CycloneBOOT static bootloader is responsible for checking the validity of the firmware and then to boot on it if it's valid. To check the firmware validity, the bootloader needs some information. 

A special image (internal image) containing the firmware and necessary information is expected by the bootloader in order for it to work properly. This image also takes into consideration the firmware start address with respect to the static bootloader size and MCU VTOR offset rules.

- First, we MUST erase external flash memory to avoid potential previous output update images triggering an update at bootloader startup.
- Second, we need to generete an internal image from the demo firmware binary. 
- Finally, we can program the internal MCU flash to load the 'internal image' following the bootloader at 0x08010000.

These steps can be performed manually or using dedicated scripts.

**Manual Method** :

From within the demo project directory, execute the following commands to:
- Erase external flash memory **(1\*)**: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -SE 0 31 -EL "C:\Program Files (x86)\STMicroelectronics\STM32 ST-LINK Utility\ST-LINK Utility\ExternalLoader\MX25L512G_STM32F769I-DISCO.stldr"` 
- Generate internal image: `..\..\..\..\..\utils\AppImageBuilder\bin\app_image_builder_windows.exe -input https_client_iap_single_bank_demo.bin -output https_client_iap_single_bank_demo_image_int.img -fv 1.0.0 -int`
- Copy the internal image into a binary (.bin) file:
`copy https_client_iap_single_bank_demo_image_int.img https_client_iap_single_bank_demo_image_int.img.bin`
- Load internal image into flash: `ST-LINK_CLI.exe -c ID=0 SWD -Halt -Rst -P https_client_iap_single_bank_demo_image_int.img.bin 0x08010000`

**Using the provided script** :

From ../scripts directory, run the following script to:
- Erase external flash memory **(1\*)**: `erase_external_flash.bat`
- Generate internal image: `generate_https_client_iap_single_bank_internal_image.bat`. You will get this image `https_client_iap_single_bank_demo_image_int.img` in ../scripts directory.
- Load internal image into flash: `load_https_client_iap_single_bank_internal_image.bat`

> Note: 
> - **(1\*)** : It's only an example to erase an external flash of an STM32 board (nucleo/disco/eval) it may not be available for your board as it is. 

### Step #5 : Test the Demo

**Note: Remember that the demo expects a specific scenario that has been chosen and the update image MUST also match that scenario.**

1. If not already done configure the board in single bank mode as explained in *Step #1* (only needed for MCU that support dual bank flash), else skip this step.
2. If not already done load static bootloader as explained in *Step #2*, else skip this step.
3. If not already done compile the demo for the choosen scenario as explained in *Step #3*, else skip this step.
4. Generate and load internal image for the inital firmware as explained in *Step #5*
5. Generate firmware update image as explained in *Step #4* in regards of the choosen scenario.
6. Open your favorite serial console (115200 bauds). 
7. Click on the reset button to restart the demo.
8. Connect the board to a router with an Ethernet cable.
9. You should be able read to the IP address of the board along with a welcome message and the red LED (LD3) should be blinking.
10. Click on the User Button (B1 USER) to initiate a firmware update.
11. If no error occurs during the reception of the image, the device will update and reboot.
12. With the new update, the green LED (LD1) shoud be blinking.
14. You can reproduce the step *10.* to *14.* to trigger another update. 


> Note: If you want to test another scenario restart from step *3.*