//Dependencies
#include <stdlib.h>
#include <stdio.h>
#include <stdint.h>
#include "stm32f7xx.h"
#include "stm32f7xx_hal.h"
#include "stm32f769i_discovery.h"
#include "stm32f769i_discovery_lcd.h"
#include "drivers/flash/flash.h"
#include "drivers/flash/stm32f7xx_flash_driver.h"
#include "os_port.h"
#include "debug.h"

#include "core/image.h"
#include "test.h"
#include "drivers/mcu/arm/stm32f7xx_mcu_driver.h"
#include "drivers/flash/mx25l512_flash_driver.h"
#include "bootloader/boot.h"
#include "bootloader/boot_fallback.h"

//Prototypes
error_t testSetFlashDriver(void);
error_t testFlashDriver(const FlashDriver *memDriver);

error_t testFlashDriverErase_Mx25l512FlashDriver(void);
error_t testFlashDriverErase_Stm32f7xxFlashDriver(void);

void testRoutine(void)
{
	error_t error;
	
	TRACE_INFO("\r\n");
	TRACE_INFO("=== START TEST ROUTINE ===\r\n");
	
	do
	{
		//Put test code here
		//error = testFlashDriver(&mx25l512FlashDriver);
      //error = testSetFlashDriver();
      error = testFlashDriverErase_Mx25l512FlashDriver();
      error = testFlashDriverErase_Stm32f7xxFlashDriver();
		//Is any error?
		if(error)
			break;
		
	}while(0);
	
	
	TRACE_INFO("=== END TEST ROUTINE ===\r\n");
	TRACE_INFO("\r\n");
}


error_t testFlashDriver(const FlashDriver *memDriver)
{
	error_t error;
   const FlashInfo *memInfo;
   uint8_t buffer[512];
   uint32_t addr;
   uint32_t length;
   
   memset(buffer, 0xCC, sizeof(buffer));
   error = NO_ERROR;
	
   do
   {
      error = memDriver->init();
      if(error)
         break;
      
      error = memDriver->getInfo(&memInfo);
      if(error)
         break;
      
      /////////////////////////////////////////////
      // Read 4B data from Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 4;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      // Write 4B data in Flash memory
      addr = memInfo->memAddr + 0x110000;
      length = 4;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Read 128B data from Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 128;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      length = 128;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Read 128B data from Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 512;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      length = 512;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Erase 128B data in Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 128;
      error = memDriver->erase(addr, length);
      if(error)
         break;
      
      TRACE_INFO("- Erase %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      error = memDriver->erase(addr, length);
      if(error)
         break;
      
      TRACE_INFO("- Erase %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Read 128B data from Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 512;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      length = 512;
      error = memDriver->read(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Read %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Write 4B data in Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 4;
      memset(buffer, 0x11, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 1):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      memset(buffer, 0x22, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 2):\r\n", length, addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Write 128B data in Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 128;
      memset(buffer, 0x13, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 1):\r\n",  length,  addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      memset(buffer, 0x23, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 2):\r\n",  length,  addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      /////////////////////////////////////////////
      // Write 512B data in Flash memory
      
      addr = memInfo->memAddr + 0x10000;
      length = 512;
      memset(buffer, 0x14, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 1):\r\n",  length,  addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
      
      addr = memInfo->memAddr + 0x110000;
      memset(buffer, 0x24, length);
      error = memDriver->write(addr, buffer, length);
      if(error)
         break;
      
      TRACE_INFO("- Write %ld bytes at 0x%lX (Bank 2):\r\n",  length,  addr);
      TRACE_INFO_ARRAY("BUFF:", buffer, length);
      TRACE_INFO("\r\n");
   }while(0);
   
   return error;
}


error_t testSetFlashDriver(void)
{
   error_t error;
   BootContext bootContextTest;
   
   error = NO_ERROR;
   
   //Init bootloader context
   error = bootInit(&bootContextTest);
   if(error != NO_ERROR)
      return ERROR_FAILURE;
   
   do
   {
      //TEST 1 Memory driver OK
      error = bootSetPrimMemDriver(&bootContextTest, &stm32f7xxFlashDriver);
      if(error != NO_ERROR)
         break;
      
      //TEST 2 Memory driver NULL
      error = bootSetPrimMemDriver(&bootContextTest, NULL);
      if(error != ERROR_INVALID_PARAMETER)
         break;
      
      //TEST 3 Memory driver OK and slot 1 & 2 OK
      do
      {
         error = bootSetPrimMemDriver(&bootContextTest, &stm32f7xxFlashDriver);
         if(error) break;
         error = bootSetPrimMemSlot(&bootContextTest, 0x08010000, 0xF0000, 0);
         error = bootSetPrimMemSlot(&bootContextTest, 0x08110000, 0xF0000, 1);
      }while(0);
      if(error != NO_ERROR)
         break;
      
      //TEST 4 Memory driver OK and slot 1 out of range, slot 2 OK
      error = bootSetPrimMemDriver(&bootContextTest, &stm32f7xxFlashDriver);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08010000, 0x200000, 0);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08110000, 0xF0000, 1);
      if(error != ERROR_INVALID_PARAMETER)
         break;
      
      //TEST 5 Memory driver OK and slot 1 & 2 overlaps
      error = bootSetPrimMemDriver(&bootContextTest, &stm32f7xxFlashDriver);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08010000, 0xF0010, 0);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08100000, 0xF0000, 1);
      if(error != ERROR_INVALID_PARAMETER)
         break;
      
      //TEST 6 Memory driver OK and slot 1 OK but slot 2 index out of range
      error = bootSetPrimMemDriver(&bootContextTest, &stm32f7xxFlashDriver);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08010000, 0xF0000, 0);
      error = bootSetPrimMemSlot(&bootContextTest, 0x08100000, 0xF0000, 2);
      if(error != ERROR_INVALID_PARAMETER)
         break;
   }while(0);
   
   if(error)
      return ERROR_FAILURE;
   
   return NO_ERROR;
}

error_t testFlashDriverErase_Mx25l512FlashDriver(void)
{
   FlashDriver *memDriver;
   uint8_t buffer[512];
   uint8_t buffer2[512];
   error_t error;
   
   error = NO_ERROR;
   memset(buffer, 0, sizeof(buffer));
   memset(buffer2, 0xFF, sizeof(buffer2));
   
   memDriver = (FlashDriver *)&mx25l512FlashDriver;
   
   error = memDriver->init();
   if(error) 
      return error;
   
   TRACE_INFO("Testing erase memory driver function (mx25l512FlashDriver)...\r\n");
   
   do
   {
      //Test 1 --------------------------------------------------------------
      //Wrong erase address
      
      error = memDriver->erase(0x00000001, 10);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 2 --------------------------------------------------------------
      //Wrong erase size 1
      
      error = memDriver->erase(0x00000000, MX25L512_SIZE+1);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 3 --------------------------------------------------------------
      //Wrong erase size 2
      
      error = memDriver->erase(0x00000000+ MX25L512_SUBSECTORS_SIZE*(MX25L512_SUBSECTORS_NUMBER-2), MX25L512_SUBSECTORS_SIZE*3);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 4 --------------------------------------------------------------
      //Valid erase of a the first sector
      
      //Write data in first sector
      memset(buffer, 0xEF, sizeof(buffer));
      error = memDriver->write(0x00000000, buffer, sizeof(buffer));
      if(error)
         return error;
      
      //Write data in second sector
      memset(buffer, 0xAA, sizeof(buffer));
      error = memDriver->write(0x00000000+MX25L512_SUBSECTORS_SIZE, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Erase data in first sector
      error = memDriver->erase(0x00000000, 10);
      if(error)
         break;
      else
      {
         //Read data of the first sector
         error = memDriver->read(0x00000000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the first sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the second sector
         error = memDriver->read(0x00000000+MX25L512_SUBSECTORS_SIZE, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be different
         if(memcmp(buffer, buffer2, sizeof(buffer)) == 0)
         {
            error = ERROR_FAILURE;
            break;
         }
      }
      
      //Test 5 --------------------------------------------------------------
      //Valid erase of the sector 1 & 2
      
      //Write data in first sector
      memset(buffer, 0xEF, sizeof(buffer));
      error = memDriver->write(0x00000000, buffer, sizeof(buffer));
      if(error)
         return error;
      
      //Write data in second sector
      memset(buffer, 0xAA, sizeof(buffer));
      error = memDriver->write(0x00000000+MX25L512_SUBSECTORS_SIZE, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Write data in second sector
      memset(buffer, 0xBB, sizeof(buffer));
      error = memDriver->write(0x00000000+MX25L512_SUBSECTORS_SIZE*2, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Erase data in first sector
      error = memDriver->erase(0x00000000, MX25L512_SUBSECTORS_SIZE*2);
      if(error)
         break;
      else
      {
         //Read data of the first sector
         error = memDriver->read(0x00000000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the first sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the second sector
         error = memDriver->read(0x00000000+MX25L512_SUBSECTORS_SIZE, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the third sector
         error = memDriver->read(0x00000000+MX25L512_SUBSECTORS_SIZE*2, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be different
         if(memcmp(buffer, buffer2, sizeof(buffer)) == 0)
         {
            error = ERROR_FAILURE;
            break;
         }
      }      
   }while(0);
   
   if(error)
   {
      printf("Test failed!\r\n");
   }
   else
      printf("Test OK.\r\n");
   
   return error;
}

error_t testFlashDriverErase_Stm32f7xxFlashDriver(void)
{
   FlashDriver *memDriver;
   uint8_t buffer[512];
   uint8_t buffer2[512];
   error_t error;
   
   error = NO_ERROR;
   memset(buffer, 0, sizeof(buffer));
   memset(buffer2, 0xFF, sizeof(buffer2));
   
   memDriver = (FlashDriver *)&stm32f7xxFlashDriver;
   
   error = memDriver->init();
   if(error) 
      return error;
   
   TRACE_INFO("Testing erase memory driver function (stm32f7xxFlashDriver)...\r\n");
   
   do
   {
      //Test 1 --------------------------------------------------------------
      //Wrong erase address
      
      error = memDriver->erase(0x08010001, 10);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 2 --------------------------------------------------------------
      //Wrong erase size 1
      
      error = memDriver->erase(0x08010000, STM32F7xx_SIZE+1);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 3 --------------------------------------------------------------
      //Wrong erase size 2
      
      error = memDriver->erase(0x08010000+ 0x28000, 0x1D0000);
      if(!error)
      {
         error = ERROR_FAILURE;
         break;
      }
      
      //Test 4 --------------------------------------------------------------
      //Valid erase of a the first sector
      
      //Write data in first sector
      memset(buffer, 0xEF, sizeof(buffer));
      error = memDriver->write(0x08010000, buffer, sizeof(buffer));
      if(error)
         return error;
      
      //Write data in second sector
      memset(buffer, 0xAA, sizeof(buffer));
      error = memDriver->write(0x08018000, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Erase data in first sector
      error = memDriver->erase(0x08010000, 10);
      if(error)
         break;
      else
      {
         //Read data of the first sector
         error = memDriver->read(0x08010000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the first sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the second sector
         error = memDriver->read(0x08018000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be different
         if(memcmp(buffer, buffer2, sizeof(buffer)) == 0)
         {
            error = ERROR_FAILURE;
            break;
         }
      }
      
      //Test 5 --------------------------------------------------------------
      //Valid erase of the sector 1 & 2
      
      //Write data in first sector
      memset(buffer, 0xEF, sizeof(buffer));
      error = memDriver->write(0x08010000, buffer, sizeof(buffer));
      if(error)
         return error;
      
      //Write data in second sector
      memset(buffer, 0xAA, sizeof(buffer));
      error = memDriver->write(0x08018000, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Write data in second sector
      memset(buffer, 0xBB, sizeof(buffer));
      error = memDriver->write(0x08020000, buffer, sizeof(buffer));
      if(error) 
         return error;
      
      //Erase data in first sector
      error = memDriver->erase(0x08010000, 0x10000);
      if(error)
         break;
      else
      {
         //Read data of the first sector
         error = memDriver->read(0x08010000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the first sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the second sector
         error = memDriver->read(0x08018000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be equal
         if(memcmp(buffer, buffer2, sizeof(buffer)) != 0)
         {
            error = ERROR_FAILURE;
            break;
         }
         
         //Read data of the third sector
         error = memDriver->read(0x08020000, buffer, sizeof(buffer));
         if(error)
            return error;
         
         //Compare data of the second sector with reset buffer (fill with 0xFF)
         //They must be different
         if(memcmp(buffer, buffer2, sizeof(buffer)) == 0)
         {
            error = ERROR_FAILURE;
            break;
         }
      }      
   }while(0);
   
   if(error)
   {
      printf("Test failed!\r\n");
   }
   else
      printf("Test OK.\r\n");
   
   return error;
}
